summaryrefslogtreecommitdiff
path: root/var
diff options
context:
space:
mode:
authorKen Raffenetti <raffenet@users.noreply.github.com>2019-11-27 16:34:46 -0600
committerAdam J. Stewart <ajstewart426@gmail.com>2019-11-27 16:34:46 -0600
commit85ce22a0b848d03f066137d2efd6a65d3f6c632c (patch)
tree8fd9ca126c8183e8f60dc9e171f63474df9d2499 /var
parent484dab6bacb851c15b44e626119d1bb04e100923 (diff)
downloadspack-85ce22a0b848d03f066137d2efd6a65d3f6c632c.tar.gz
spack-85ce22a0b848d03f066137d2efd6a65d3f6c632c.tar.bz2
spack-85ce22a0b848d03f066137d2efd6a65d3f6c632c.tar.xz
spack-85ce22a0b848d03f066137d2efd6a65d3f6c632c.zip
mpich: Add ucx dependency (#13921)
Diffstat (limited to 'var')
-rw-r--r--var/spack/repos/builtin/packages/mpich/package.py9
1 files changed, 7 insertions, 2 deletions
diff --git a/var/spack/repos/builtin/packages/mpich/package.py b/var/spack/repos/builtin/packages/mpich/package.py
index 9ad46f7b91..8e0de0cadf 100644
--- a/var/spack/repos/builtin/packages/mpich/package.py
+++ b/var/spack/repos/builtin/packages/mpich/package.py
@@ -94,6 +94,8 @@ spack package at this time.''',
# See https://github.com/pmodels/mpich/issues/3665
depends_on('libfabric@:1.6', when='device=ch3 netmod=ofi')
+ depends_on('ucx', when='netmod=ucx')
+
depends_on('libpciaccess', when="+pci")
depends_on('libxml2')
@@ -217,10 +219,13 @@ spack package at this time.''',
config_args.append(device_config)
# Specify libfabric's path explicitly, otherwise configure might fall
# back to an embedded version of libfabric.
if 'netmod=ofi' in spec:
config_args.append('--with-libfabric={0}'.format(
spec['libfabric'].prefix))
+ if 'netmod=ucx' in spec:
+ config_args.append('--with-ucx={0}'.format(
+ spec['ucx'].prefix))
return config_args
@@ -217,10 +219,13 @@ spack package at this time.''',
config_args.append(device_config)
- # Specify libfabric's path explicitly, otherwise configure might fall
- # back to an embedded version of libfabric.
+ # Specify libfabric or ucx path explicitly, otherwise
+ # configure might fall back to an embedded version.
if 'netmod=ofi' in spec:
config_args.append('--with-libfabric={0}'.format(